#ifndef APPLICATIONVIEW_H
#define APPLICATIONVIEW_H

#include <QWidget>
#include "ApplicationController.h"

class ApplicationView : public QWidget
{
    Q_OBJECT

    Q_PROPERTY(QString friendlyName READ friendlyName);

public:
    explicit             ApplicationView    (QWidget *parent = 0);

    virtual QString      friendlyName       () const = 0;

    virtual void         setController      (ApplicationController *controller) = 0;

    /*
    virtual void         suspend            () = 0;
    virtual void         resume             () = 0;
    */
};

#endif // APPLICATIONVIEW_H
